@@ -91,7 +91,7 @@ char * input_expectation[n_expectations] = {
 "bytes in range 90-bf: '\\x90-\\xbf'",
 "bytes in range a0-bf: '\\xa0-\\xbf'",
 };
-unsigned char allowed[n_expectations][MAXBYTE] = {
+unsigned char allowed[n_expectations][JSON3MAXBYTE] = {
 /* whitespace */
 {0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
